@@ -1,10 +1,16 @@
 package Sah::Schema::cryptocurrency::code_or_name;
 
-our $DATE = '2018-04-06'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2018-05-29'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [str => {
     summary => 'Cryptocurrency code or name',
+    description => <<'_',
+
+Cryptocurrency code or name that is listed in <pm:CryptoCurrency::Catalog>, e.g.
+BTC, "Bitcoin Cash", eth.
+
+_
     'x.completion' => 'cryptocurrency_code_or_name',
 }, {}];
 
@@ -23,7 +29,12 @@ Sah::Schema::cryptocurrency::code_or_name - Cryptocurrency code or name
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::cryptocurrency::code_or_name (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2018-04-06.
+This document describes version 0.006 of Sah::Schema::cryptocurrency::code_or_name (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2018-05-29.
+
+=head1 DESCRIPTION
+
+Cryptocurrency code or name that is listed in L<CryptoCurrency::Catalog>, e.g.
+BTC, "Bitcoin Cash", eth.
 
 =head1 HOMEPAGE
 
